@@ -86,7 +86,7 @@ class CVSLogisticSubTypes(str, Enum):
 class CartConfig(BaseCartConfig):
     buyer_name: str = ""
     buyer_phone: str = ""
-    buyer_email: EmailStr
+    buyer_email: str = ""
     buyer_zip: str = ""
     buyer_city: str = ""
     buyer_district: str = ""
@@ -139,6 +139,13 @@ class CartConfig(BaseCartConfig):
         except KeyError:
             raise ValueError("subtype_not_valid")
 
+    @validator("buyer_email")
+    def validate_buyer_email(cls, value: str) -> str:
+        if not value:
+            return ""
+        buyer_email = EmailStr.validate(value)
+        return buyer_email
+
 
 OptionalCartConfig = CartConfig.model_with_optional_fields()
 
