@@ -499,7 +499,7 @@ class SFLogisticsCreate:
             # 收件人訊息
             "receiverInfo": {
                 # 寄件人名字
-                "contact": order.receiver_name,
+                "contact": extra_data.get("buyer_name", ""),
                 # 寄件國家/地區
                 "country": receiver_country,
                 # 郵編
@@ -511,9 +511,9 @@ class SFLogisticsCreate:
                 # 區
                 "regionThird": receiver_region_third,
                 "address": receiver_address,
-                "email": order.receiver_email,
+                "email": extra_data.get("buyer_email", ""),
                 "cargoType": extra_data.get("cargo_type", 1),
-                "phoneNo": order.receiver_phone,
+                "phoneNo": extra_data.get("buyer_phone", ""),
             },
             # 包裹訊息
             "parcelInfoList": self.generate_items(order.items),
